@@ -411,6 +411,16 @@ class Proxy(proxy.Proxy):
                                        wait=wait, timeout=timeout,
                                        deploy_steps=deploy_steps)
 
+    def get_node_boot_device(self, node):
+        """Get node boot device
+
+        :param node: The value can be the name or ID of a node or a
+            :class:`~openstack.baremetal.v1.node.Node` instance.
+        :return: The node boot device
+        """
+        res = self._get_resource(_node.Node, node)
+        return res.get_boot_device()
+
     def set_node_boot_device(self, node, boot_device, persistent=False):
         """Set node boot device
 
@@ -424,6 +434,16 @@ class Proxy(proxy.Proxy):
         res = self._get_resource(_node.Node, node)
         return res.set_boot_device(self, boot_device, persistent=persistent)
 
+    def get_node_supported_boot_devices(self, node):
+        """Get supported boot devices for node
+
+        :param node: The value can be the name or ID of a node or a
+            :class:`~openstack.baremetal.v1.node.Node` instance.
+        :return: The node boot device
+        """
+        res = self._get_resource(_node.Node, node)
+        return res.get_supported_boot_devices()
+
     def set_node_boot_mode(self, node, target):
         """Make a request to change node's boot mode
 
@@ -445,6 +465,21 @@ class Proxy(proxy.Proxy):
         res = self._get_resource(_node.Node, node)
         return res.set_secure_boot(self, target)
 
+    def inject_nmi_to_node(self, node):
+        """Inject NMI to node.
+
+        Injects a non-maskable interrupt (NMI) message to the node. This is
+        used when response time is critical, such as during non-recoverable
+        hardware errors. In addition, virsh inject-nmi is useful for triggering
+        a crashdump in Windows guests.
+
+        :param node: The value can be the name or ID of a node or a
+            :class:`~openstack.baremetal.v1.node.Node` instance.
+        :return: None
+        """
+        res = self._get_resource(_node.Node, node)
+        res.inject_nmi(self)
+
     def wait_for_nodes_provision_state(self, nodes, expected_state,
                                        timeout=None,
                                        abort_on_failed_state=True,
@@ -1088,10 +1123,12 @@ class Proxy(proxy.Proxy):
     def call_node_vendor_passthru(self, node, verb, method, body=None):
         """Calls vendor_passthru for a node.
 
-        :param session: The session to use for making this request.
+        :param node: The value can be the name or ID of a node or a
+            :class:`~openstack.baremetal.v1.node.Node` instance.
         :param verb: The HTTP verb, one of GET, SET, POST, DELETE.
         :param method: The method to call using vendor_passthru.
         :param body: The JSON body in the HTTP call.
+        :returns: The raw response from the method.
         """
         res = self._get_resource(_node.Node, node)
         return res.call_vendor_passthru(self, verb, method, body)
@@ -1099,11 +1136,43 @@ class Proxy(proxy.Proxy):
     def list_node_vendor_passthru(self, node):
         """Lists vendor_passthru for a node.
 
-        :param session: The session to use for making this request.
+        :param node: The value can be the name or ID of a node or a
+            :class:`~openstack.baremetal.v1.node.Node` instance.
+        :returns: A list of vendor_passthru methods for the node.
         """
         res = self._get_resource(_node.Node, node)
         return res.list_vendor_passthru(self)
 
+    def get_node_console(self, node):
+        """Get the console for a node.
+
+        :param node: The value can be the name or ID of a node or a
+            :class:`~openstack.baremetal.v1.node.Node` instance.
+        :returns: Connection information for the console.
+        """
+        res = self._get_resource(_node.Node, node)
+        return res.get_node_console(self)
+
+    def enable_node_console(self, node):
+        """Enable the console for a node.
+
+        :param node: The value can be the name or ID of a node or a
+            :class:`~openstack.baremetal.v1.node.Node` instance.
+        :returns: None
+        """
+        res = self._get_resource(_node.Node, node)
+        return res.set_console_mode(self, True)
+
+    def disable_node_console(self, node):
+        """Disable the console for a node.
+
+        :param node: The value can be the name or ID of a node or a
+            :class:`~openstack.baremetal.v1.node.Node` instance.
+        :returns: None
+        """
+        res = self._get_resource(_node.Node, node)
+        return res.set_console_mode(self, False)
+
     def set_node_traits(self, node, traits):
         """Set traits for a node.
 
