@@ -15,14 +15,15 @@
 # openstack.resource.Resource.list and openstack.resource2.Resource.list
 import types  # noqa
 
-from openstack.cloud import _normalize
 from openstack.cloud import _utils
 from openstack.cloud import exc
+from openstack.dns.v2._proxy import Proxy
 from openstack import exceptions
 from openstack import resource
 
 
-class DnsCloudMixin(_normalize.Normalizer):
+class DnsCloudMixin:
+    dns: Proxy
 
     def list_zones(self, filters=None):
         """List all available zones.
@@ -64,11 +65,11 @@ class DnsCloudMixin(_normalize.Normalizer):
         :param name: Name of the zone being created.
         :param zone_type: Type of the zone (primary/secondary)
         :param email: Email of the zone owner (only
-                      applies if zone_type is primary)
+            applies if zone_type is primary)
         :param description: Description of the zone
         :param ttl: TTL (Time to live) value in seconds
         :param masters: Master nameservers (only applies
-                        if zone_type is secondary)
+            if zone_type is secondary)
 
         :returns: a dict representing the created zone.
 
@@ -111,11 +112,11 @@ class DnsCloudMixin(_normalize.Normalizer):
 
         :param name_or_id: Name or ID of the zone being updated.
         :param email: Email of the zone owner (only
-                      applies if zone_type is primary)
+            applies if zone_type is primary)
         :param description: Description of the zone
         :param ttl: TTL (Time to live) value in seconds
         :param masters: Master nameservers (only applies
-                        if zone_type is secondary)
+            if zone_type is secondary)
 
         :returns: a dict representing the updated zone.
 
