@@ -16,14 +16,16 @@
 # import jsonpatch
 import types  # noqa
 
-from openstack.cloud import _normalize
 from openstack.cloud import _utils
 from openstack.cloud import exc
 from openstack import exceptions
+from openstack.network.v2._proxy import Proxy
 from openstack import proxy
+from openstack import utils
 
 
-class SecurityGroupCloudMixin(_normalize.Normalizer):
+class SecurityGroupCloudMixin:
+    network: Proxy
 
     def __init__(self):
         self.secgroup_source = self.config.config['secgroup_source']
@@ -39,7 +41,8 @@ class SecurityGroupCloudMixin(_normalize.Normalizer):
         """List all available security groups.
 
         :param filters: (optional) dict of filter conditions to push down
-        :returns: A list of security group ``munch.Munch``.
+        :returns: A list of security group
+            ``openstack.network.v2.security_group.SecurityGroup``.
 
         """
         # Security groups not supported
@@ -85,8 +88,9 @@ class SecurityGroupCloudMixin(_normalize.Normalizer):
             A string containing a jmespath expression for further filtering.
             Example:: "[?last_name==`Smith`] | [?other.gender]==`Female`]"
 
-        :returns: A security group ``munch.Munch`` or None if no matching
-            security group is found.
+        :returns: A security group
+            ``openstack.network.v2.security_group.SecurityGroup``
+            or None if no matching security group is found.
 
         """
         return _utils._get_entity(
@@ -96,7 +100,8 @@ class SecurityGroupCloudMixin(_normalize.Normalizer):
         """ Get a security group by ID
 
         :param id: ID of the security group.
-        :returns: A security group ``munch.Munch``.
+        :returns: A security group
+            ``openstack.network.v2.security_group.SecurityGroup``.
         """
         if not self._has_secgroups():
             raise exc.OpenStackCloudUnavailableFeature(
@@ -125,7 +130,8 @@ class SecurityGroupCloudMixin(_normalize.Normalizer):
             on (admin-only).
         :param string stateful: Whether the security group is stateful or not.
 
-        :returns: A ``munch.Munch`` representing the new security group.
+        :returns: A ``openstack.network.v2.security_group.SecurityGroup``
+            representing the new security group.
 
         :raises: OpenStackCloudException on operation error.
         :raises: OpenStackCloudUnavailableFeature if security groups are
@@ -199,7 +205,8 @@ class SecurityGroupCloudMixin(_normalize.Normalizer):
         :param string name: New name for the security group.
         :param string description: New description for the security group.
 
-        :returns: A ``munch.Munch`` describing the updated security group.
+        :returns: A ``openstack.network.v2.security_group.SecurityGroup``
+            describing the updated security group.
 
         :raises: OpenStackCloudException on operation error.
         """
@@ -287,7 +294,8 @@ class SecurityGroupCloudMixin(_normalize.Normalizer):
             on (admin-only).
         :param string description:
             Description of the rule, max 255 characters.
-        :returns: A ``munch.Munch`` representing the new security group rule.
+        :returns: A ``openstack.network.v2.security_group.SecurityGroup``
+            representing the new security group rule.
 
         :raises: OpenStackCloudException on operation error.
         """
@@ -417,3 +425,124 @@ class SecurityGroupCloudMixin(_normalize.Normalizer):
     def _use_neutron_secgroups(self):
         return (self.has_service('network')
                 and self.secgroup_source == 'neutron')
+
+    def _normalize_secgroups(self, groups):
+        """Normalize the structure of security groups
+
+        This makes security group dicts, as returned from nova, look like the
+        security group dicts as returned from neutron. This does not make them
+        look exactly the same, but it's pretty close.
+
+        :param list groups: A list of security group dicts.
+
+        :returns: A list of normalized dicts.
+        """
+        ret = []
+        for group in groups:
+            ret.append(self._normalize_secgroup(group))
+        return ret
+
+    # TODO(stephenfin): Remove this once we get rid of support for nova
+    # secgroups
+    def _normalize_secgroup(self, group):
+
+        ret = utils.Munch()
+        # Copy incoming group because of shared dicts in unittests
+        group = group.copy()
+
+        # Discard noise
+        self._remove_novaclient_artifacts(group)
+
+        rules = self._normalize_secgroup_rules(
+            group.pop('security_group_rules', group.pop('rules', [])))
+        project_id = group.pop('tenant_id', '')
+        project_id = group.pop('project_id', project_id)
+
+        ret['location'] = self._get_current_location(project_id=project_id)
+        ret['id'] = group.pop('id')
+        ret['name'] = group.pop('name')
+        ret['security_group_rules'] = rules
+        ret['description'] = group.pop('description')
+        ret['properties'] = group
+
+        if self._use_neutron_secgroups():
+            ret['stateful'] = group.pop('stateful', True)
+
+        # Backwards compat with Neutron
+        if not self.strict_mode:
+            ret['tenant_id'] = project_id
+            ret['project_id'] = project_id
+            for key, val in ret['properties'].items():
+                ret.setdefault(key, val)
+
+        return ret
+
+    # TODO(stephenfin): Remove this once we get rid of support for nova
+    # secgroups
+    def _normalize_secgroup_rules(self, rules):
+        """Normalize the structure of nova security group rules
+
+        Note that nova uses -1 for non-specific port values, but neutron
+        represents these with None.
+
+        :param list rules: A list of security group rule dicts.
+
+        :returns: A list of normalized dicts.
+        """
+        ret = []
+        for rule in rules:
+            ret.append(self._normalize_secgroup_rule(rule))
+        return ret
+
+    # TODO(stephenfin): Remove this once we get rid of support for nova
+    # secgroups
+    def _normalize_secgroup_rule(self, rule):
+
+        ret = utils.Munch()
+        # Copy incoming rule because of shared dicts in unittests
+        rule = rule.copy()
+
+        ret['id'] = rule.pop('id')
+        ret['direction'] = rule.pop('direction', 'ingress')
+        ret['ethertype'] = rule.pop('ethertype', 'IPv4')
+        port_range_min = rule.get(
+            'port_range_min', rule.pop('from_port', None))
+        if port_range_min == -1:
+            port_range_min = None
+        if port_range_min is not None:
+            port_range_min = int(port_range_min)
+        ret['port_range_min'] = port_range_min
+        port_range_max = rule.pop(
+            'port_range_max', rule.pop('to_port', None))
+        if port_range_max == -1:
+            port_range_max = None
+        if port_range_min is not None:
+            port_range_min = int(port_range_min)
+        ret['port_range_max'] = port_range_max
+        ret['protocol'] = rule.pop('protocol', rule.pop('ip_protocol', None))
+        ret['remote_ip_prefix'] = rule.pop(
+            'remote_ip_prefix', rule.pop('ip_range', {}).get('cidr', None))
+        ret['security_group_id'] = rule.pop(
+            'security_group_id', rule.pop('parent_group_id', None))
+        ret['remote_group_id'] = rule.pop('remote_group_id', None)
+        project_id = rule.pop('tenant_id', '')
+        project_id = rule.pop('project_id', project_id)
+        ret['location'] = self._get_current_location(project_id=project_id)
+        ret['properties'] = rule
+
+        # Backwards compat with Neutron
+        if not self.strict_mode:
+            ret['tenant_id'] = project_id
+            ret['project_id'] = project_id
+            for key, val in ret['properties'].items():
+                ret.setdefault(key, val)
+        return ret
+
+    def _remove_novaclient_artifacts(self, item):
+        # Remove novaclient artifacts
+        item.pop('links', None)
+        item.pop('NAME_ATTR', None)
+        item.pop('HUMAN_ID', None)
+        item.pop('human_id', None)
+        item.pop('request_ids', None)
+        item.pop('x_openstack_request_ids', None)
