@@ -10,6 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from openstack import exceptions
 from openstack import resource
 from openstack import utils
 
@@ -20,6 +21,8 @@ class Agent(resource.Resource):
     resources_key = 'agents'
     base_path = '/agents'
 
+    _allow_unknown_attrs_in_body = True
+
     # capabilities
     allow_create = False
     allow_fetch = True
@@ -57,6 +60,15 @@ class Agent(resource.Resource):
     #: Whether or not the network agent is alive.
     #: *Type: bool*
     is_alive = resource.Body('alive', type=bool)
+    #: Whether or not the agent is succesffully synced towards placement.
+    #: Agents supporting the guaranteed minimum bandwidth feature share their
+    #: resource view with neutron-server and neutron-server share this view
+    #: with placement, resources_synced represents the success of the latter.
+    #: The value None means no resource view synchronization to Placement was
+    #: attempted. true / false values signify the success of the last
+    #: synchronization attempt.
+    #: *Type: bool*
+    resources_synced = resource.Body('resources_synced', type=bool)
     #: Timestamp when the network agent was last started.
     started_at = resource.Body('started_at')
     #: The messaging queue topic the network agent subscribes to.
@@ -88,6 +100,18 @@ class Agent(resource.Resource):
         url = utils.urljoin(self.base_path, self.id, 'l3-routers', router)
         session.delete(url, json=body)
 
+    def get_bgp_speakers_hosted_by_dragent(self, session):
+        """List BGP speakers hosted by a Dynamic Routing Agent
+
+        :param session: The session to communicate through.
+        :type session: :class:`~keystoneauth1.adapter.Adapter`
+        """
+        url = utils.urljoin(self.base_path, self.id, 'bgp-drinstances')
+        resp = session.get(url)
+        exceptions.raise_from_response(resp)
+        self._body.attributes.update(resp.json())
+        return resp.json()
+
 
 class NetworkHostingDHCPAgent(Agent):
     resource_key = 'agent'
