@@ -13,9 +13,7 @@
 from openstack import resource
 
 
-# NOTE: The VPN service is unmaintained, need to consider remove it
-
-class VPNService(resource.Resource):
+class VpnService(resource.Resource):
     resource_key = 'vpnservice'
     resources_key = 'vpnservices'
     base_path = '/vpn/vpnservices'
@@ -29,6 +27,12 @@ class VPNService(resource.Resource):
     allow_delete = True
     allow_list = True
 
+    _query_mapping = resource.QueryParameters(
+        'description', 'external_v4_ip', 'external_v6_ip', 'name', 'router_id',
+        'project_id', 'tenant_id', 'subnet_id',
+        is_admin_state_up='admin_state_up'
+    )
+
     # Properties
     #: Human-readable description for the vpnservice.
     description = resource.Body('description')
