@@ -25,6 +25,24 @@ class BaseResource(resource.Resource):
 
     _custom_metadata_prefix = None
     _system_metadata = dict()
+    _last_headers = dict()
+
+    def __init__(self, metadata=None, **attrs):
+        """Process and save metadata known at creation stage
+        """
+        super().__init__(**attrs)
+        if metadata is not None:
+            for k, v in metadata.items():
+                if not k.lower().startswith(
+                        self._custom_metadata_prefix.lower()):
+                    self.metadata[self._custom_metadata_prefix + k] = v
+                else:
+                    self.metadata[k] = v
+
+    def _prepare_request(self, **kwargs):
+        request = super()._prepare_request(**kwargs)
+        request.headers.update(self._calculate_headers(self.metadata))
+        return request
 
     def _calculate_headers(self, metadata):
         headers = {}
@@ -41,14 +59,15 @@ class BaseResource(resource.Resource):
             headers[header] = metadata[key]
         return headers
 
-    def set_metadata(self, session, metadata):
+    def set_metadata(self, session, metadata, refresh=True):
         request = self._prepare_request()
         response = session.post(
             request.url,
             headers=self._calculate_headers(metadata))
         self._translate_response(response, has_body=False)
-        response = session.head(request.url)
-        self._translate_response(response, has_body=False)
+        if refresh:
+            response = session.head(request.url)
+            self._translate_response(response, has_body=False)
         return self
 
     def delete_metadata(self, session, keys):
@@ -65,11 +84,19 @@ class BaseResource(resource.Resource):
         self.metadata = dict()
 
         for header in headers:
-            if header.startswith(self._custom_metadata_prefix):
+            # RADOS and other stuff in front may actually lowcase headers
+            if header.lower().startswith(
+                    self._custom_metadata_prefix.lower()
+            ):
                 key = header[len(self._custom_metadata_prefix):].lower()
                 self.metadata[key] = headers[header]
 
     def _translate_response(self, response, has_body=None, error_message=None):
+        # Save headers of the last operation for potential use (get_object of
+        # cloud layer).
+        # This must happen before invoking parent _translate_response, cause it
+        # pops known headers.
+        self._last_headers = response.headers.copy()
         super(BaseResource, self)._translate_response(
             response, has_body=has_body, error_message=error_message)
         self._set_metadata(response.headers)
