@@ -24,7 +24,7 @@ class TestMagnumServices(base.BaseFunctionalTest):
 
     def setUp(self):
         super(TestMagnumServices, self).setUp()
-        if not self.operator_cloud.has_service(
+        if not self.user_cloud.has_service(
             'container-infrastructure-management'
         ):
             self.skipTest('Container service not supported by cloud')
