@@ -11,17 +11,21 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
 import io
 import operator
 import tempfile
 import uuid
 
-from openstack import exceptions
 from openstack.cloud import exc
 from openstack.cloud import meta
+from openstack import exceptions
+from openstack.image.v1 import image as image_v1
+from openstack.image.v2 import image
 from openstack.tests import fakes
 from openstack.tests.unit import base
 
+
 IMPORT_METHODS = 'glance-direct,web-download'
 
 
@@ -44,6 +48,16 @@ class BaseTestImage(base.TestCase):
         self.fake_search_return = {'images': [self.fake_image_dict]}
         self.container_name = self.getUniqueString('container')
 
+    def _compare_images(self, exp, real):
+        self.assertDictEqual(
+            image.Image(**exp).to_dict(computed=False),
+            real.to_dict(computed=False))
+
+    def _compare_images_v1(self, exp, real):
+        self.assertDictEqual(
+            image_v1.Image(**exp).to_dict(computed=False),
+            real.to_dict(computed=False))
+
 
 class TestImage(BaseTestImage):
 
@@ -164,9 +178,10 @@ class TestImage(BaseTestImage):
                      base_url_append='v2'),
                  json=self.fake_image_dict)
         ])
-        self.assertDictEqual(
-            self.cloud._normalize_image(self.fake_image_dict),
-            self.cloud.get_image_by_id(self.image_id))
+        self._compare_images(
+            self.fake_image_dict,
+            self.cloud.get_image_by_id(self.image_id)
+        )
         self.assert_calls()
 
     def test_get_image_id(self, cloud=None):
@@ -214,9 +229,9 @@ class TestImage(BaseTestImage):
                      'image', append=['images'], base_url_append='v2'),
                  json=self.fake_search_return)
         ])
-        self.assertEqual(
-            self.cloud._normalize_images([self.fake_image_dict]),
-            self.cloud.list_images())
+        [self._compare_images(a, b) for a, b in zip(
+            [self.fake_image_dict],
+            self.cloud.list_images())]
         self.assert_calls()
 
     def test_list_images_show_all(self):
@@ -227,9 +242,9 @@ class TestImage(BaseTestImage):
                      qs_elements=['member_status=all']),
                  json=self.fake_search_return)
         ])
-        self.assertEqual(
-            self.cloud._normalize_images([self.fake_image_dict]),
-            self.cloud.list_images(show_all=True))
+        [self._compare_images(a, b) for a, b in zip(
+            [self.fake_image_dict],
+            self.cloud.list_images(show_all=True))]
         self.assert_calls()
 
     def test_list_images_show_all_deleted(self):
@@ -242,10 +257,9 @@ class TestImage(BaseTestImage):
                      qs_elements=['member_status=all']),
                  json={'images': [self.fake_image_dict, deleted_image]})
         ])
-        self.assertEqual(
-            self.cloud._normalize_images([
-                self.fake_image_dict, deleted_image]),
-            self.cloud.list_images(show_all=True))
+        [self._compare_images(a, b) for a, b in zip(
+            [self.fake_image_dict],
+            self.cloud.list_images(show_all=True))]
         self.assert_calls()
 
     def test_list_images_no_filter_deleted(self):
@@ -257,10 +271,9 @@ class TestImage(BaseTestImage):
                      'image', append=['images'], base_url_append='v2'),
                  json={'images': [self.fake_image_dict, deleted_image]})
         ])
-        self.assertEqual(
-            self.cloud._normalize_images([
-                self.fake_image_dict, deleted_image]),
-            self.cloud.list_images(filter_deleted=False))
+        [self._compare_images(a, b) for a, b in zip(
+            [self.fake_image_dict],
+            self.cloud.list_images(filter_deleted=False))]
         self.assert_calls()
 
     def test_list_images_filter_deleted(self):
@@ -272,9 +285,9 @@ class TestImage(BaseTestImage):
                      'image', append=['images'], base_url_append='v2'),
                  json={'images': [self.fake_image_dict, deleted_image]})
         ])
-        self.assertEqual(
-            self.cloud._normalize_images([self.fake_image_dict]),
-            self.cloud.list_images())
+        [self._compare_images(a, b) for a, b in zip(
+            [self.fake_image_dict],
+            self.cloud.list_images())]
         self.assert_calls()
 
     def test_list_images_string_properties(self):
@@ -287,9 +300,10 @@ class TestImage(BaseTestImage):
                  json={'images': [image_dict]}),
         ])
         images = self.cloud.list_images()
-        self.assertEqual(
-            self.cloud._normalize_images([image_dict]),
-            images)
+        [self._compare_images(a, b) for a, b in zip(
+            [image_dict],
+            images)]
+
         self.assertEqual(
             images[0]['properties']['properties'],
             'list,of,properties')
@@ -310,10 +324,9 @@ class TestImage(BaseTestImage):
                      qs_elements=['marker={marker}'.format(marker=marker)]),
                  json=self.fake_search_return)
         ])
-        self.assertEqual(
-            self.cloud._normalize_images([
-                self.fake_image_dict, self.fake_image_dict]),
-            self.cloud.list_images())
+        [self._compare_images(a, b) for a, b in zip(
+            [self.fake_image_dict],
+            self.cloud.list_images())]
         self.assert_calls()
 
     def test_create_image_put_v2_no_import(self):
@@ -533,89 +546,6 @@ class TestImage(BaseTestImage):
         self.assertEqual(self.adapter.request_history[7].text.read(),
                          self.output)
 
-    def test_create_image_import_fallback(self):
-        self.cloud.image_api_use_tasks = False
-
-        self.register_uris([
-            dict(method='GET',
-                 uri=self.get_mock_url(
-                     'image', append=['images', self.image_name],
-                     base_url_append='v2'),
-                 status_code=404),
-            dict(method='GET',
-                 uri=self.get_mock_url(
-                     'image', append=['images'],
-                     base_url_append='v2',
-                     qs_elements=['name=' + self.image_name]),
-                 validate=dict(),
-                 json={'images': []}),
-            dict(method='GET',
-                 uri=self.get_mock_url(
-                     'image', append=['images'],
-                     base_url_append='v2',
-                     qs_elements=['os_hidden=True']),
-                 json={'images': []}),
-            dict(method='POST',
-                 uri=self.get_mock_url(
-                     'image', append=['images'], base_url_append='v2'),
-                 json=self.fake_image_dict,
-                 headers={
-                     'OpenStack-image-import-methods': IMPORT_METHODS,
-                 },
-                 validate=dict(
-                     json={
-                         u'container_format': u'bare',
-                         u'disk_format': u'qcow2',
-                         u'name': self.image_name,
-                         u'owner_specified.openstack.md5':
-                             self.fake_image_dict[
-                                 'owner_specified.openstack.md5'],
-                         u'owner_specified.openstack.object': self.object_name,
-                         u'owner_specified.openstack.sha256':
-                             self.fake_image_dict[
-                                 'owner_specified.openstack.sha256'],
-                         u'visibility': u'private',
-                         u'tags': [u'tag1', u'tag2']})
-                 ),
-            dict(method='PUT',
-                 uri=self.get_mock_url(
-                     'image', append=['images', self.image_id, 'file'],
-                     base_url_append='v2'),
-                 request_headers={'Content-Type': 'application/octet-stream'},
-                 status_code=403),
-            dict(method='PUT',
-                 uri=self.get_mock_url(
-                     'image', append=['images', self.image_id, 'stage'],
-                     base_url_append='v2'),
-                 request_headers={'Content-Type': 'application/octet-stream'}),
-            dict(method='POST',
-                 uri=self.get_mock_url(
-                     'image', append=['images', self.image_id, 'import'],
-                     base_url_append='v2'),
-                 json={'method': {'name': 'glance-direct'}}),
-            dict(method='GET',
-                 uri=self.get_mock_url(
-                     'image', append=['images', self.fake_image_dict['id']],
-                     base_url_append='v2'
-                 ),
-                 json=self.fake_image_dict),
-            dict(method='GET',
-                 uri=self.get_mock_url(
-                     'image', append=['images'], base_url_append='v2'),
-                 complete_qs=True,
-                 json=self.fake_search_return)
-        ])
-
-        self.cloud.create_image(
-            self.image_name, self.imagefile.name, wait=True, timeout=1,
-            tags=['tag1', 'tag2'],
-            is_public=False, validate_checksum=True,
-        )
-
-        self.assert_calls()
-        self.assertEqual(self.adapter.request_history[7].text.read(),
-                         self.output)
-
     def test_create_image_task(self):
         self.cloud.image_api_use_tasks = True
         endpoint = self.cloud._object_store_client.get_endpoint()
@@ -696,10 +626,10 @@ class TestImage(BaseTestImage):
                      object=self.image_name),
                  status_code=201,
                  validate=dict(
-                     headers={'x-object-meta-x-sdk-md5':
+                     headers={'X-Object-Meta-x-sdk-md5':
                               self.fake_image_dict[
                                   'owner_specified.openstack.md5'],
-                              'x-object-meta-x-sdk-sha256':
+                              'X-Object-Meta-x-sdk-sha256':
                               self.fake_image_dict[
                                   'owner_specified.openstack.sha256']})
                  ),
@@ -792,12 +722,12 @@ class TestImage(BaseTestImage):
         self.assert_calls()
 
     def test_delete_autocreated_no_tasks(self):
-        self.use_nothing()
+        self.use_keystone_v3()
         self.cloud.image_api_use_tasks = False
         deleted = self.cloud.delete_autocreated_image_objects(
             container=self.container_name)
         self.assertFalse(deleted)
-        self.assert_calls()
+        self.assert_calls([])
 
     def test_delete_image_task(self):
         self.cloud.image_api_use_tasks = True
@@ -904,8 +834,10 @@ class TestImage(BaseTestImage):
                      'Date': 'Thu, 16 Nov 2017 15:24:30 GMT',
                      'Accept-Ranges': 'bytes',
                      'Content-Type': 'application/octet-stream',
-                     self.cloud._OBJECT_AUTOCREATE_KEY: 'true',
-                     'Etag': fakes.NO_MD5}),
+                     ('X-Object-Meta-'
+                      + self.cloud._OBJECT_AUTOCREATE_KEY): 'true',
+                     'Etag': fakes.NO_MD5,
+                     'X-Static-Large-Object': 'false'}),
             dict(method='DELETE',
                  uri='{endpoint}/{container}/{object}'.format(
                      endpoint=endpoint, container=self.container_name,
@@ -921,9 +853,6 @@ class TestImage(BaseTestImage):
     def _image_dict(self, fake_image):
         return self.cloud._normalize_image(meta.obj_to_munch(fake_image))
 
-    def _munch_images(self, fake_image):
-        return self.cloud._normalize_images([fake_image])
-
     def _call_create_image(self, name, **kwargs):
         imagefile = tempfile.NamedTemporaryFile(delete=False)
         imagefile.write(b'\0')
@@ -973,7 +902,8 @@ class TestImage(BaseTestImage):
                  json={'images': [ret]}),
         ])
         self._call_create_image(self.image_name)
-        self.assertEqual(self._munch_images(ret), self.cloud.list_images())
+        [self._compare_images_v1(b, a) for a, b in zip(
+            self.cloud.list_images(), [ret])]
 
     def test_create_image_put_v1_bad_delete(self):
         self.cloud.config.config['image_api_version'] = '1'
@@ -1041,7 +971,7 @@ class TestImage(BaseTestImage):
         ret['status'] = 'success'
 
         self.cloud.update_image_properties(
-            image=self._image_dict(ret),
+            image=image.Image.existing(**ret),
             **{'owner_specified.openstack.object': 'images/{name}'.format(
                 name=self.image_name)})
 
@@ -1362,7 +1292,7 @@ class TestImage(BaseTestImage):
 
         self._call_create_image(
             self.image_name, min_disk='0', min_ram=0,
-            properties={'int_v': 12345}, protected=False)
+            properties={'int_v': 12345}, is_protected=False)
 
         self.assert_calls()
 
@@ -1385,9 +1315,9 @@ class TestImageSuburl(BaseTestImage):
                      'image', append=['images'], base_url_append='v2'),
                  json=self.fake_search_return)
         ])
-        self.assertEqual(
-            self.cloud._normalize_images([self.fake_image_dict]),
-            self.cloud.list_images())
+        [self._compare_images(b, a) for a, b in zip(
+            self.cloud.list_images(),
+            [self.fake_image_dict])]
         self.assert_calls()
 
     def test_list_images_paginated(self):
@@ -1405,10 +1335,9 @@ class TestImageSuburl(BaseTestImage):
                      qs_elements=['marker={marker}'.format(marker=marker)]),
                  json=self.fake_search_return)
         ])
-        self.assertEqual(
-            self.cloud._normalize_images([
-                self.fake_image_dict, self.fake_image_dict]),
-            self.cloud.list_images())
+        [self._compare_images(b, a) for a, b in zip(
+            self.cloud.list_images(),
+            [self.fake_image_dict, self.fake_image_dict])]
         self.assert_calls()
 
 
@@ -1474,7 +1403,7 @@ class TestImageVolume(BaseTestImage):
             self.get_cinder_discovery_mock_dict(),
             dict(method='POST',
                  uri=self.get_mock_url(
-                     'volumev2', append=['volumes', self.volume_id, 'action']),
+                     'volumev3', append=['volumes', self.volume_id, 'action']),
                  json={'os-volume_upload_image': {'image_id': self.image_id}},
                  validate=dict(json={
                      u'os-volume_upload_image': {
@@ -1506,7 +1435,7 @@ class TestImageVolume(BaseTestImage):
             self.get_cinder_discovery_mock_dict(),
             dict(method='POST',
                  uri=self.get_mock_url(
-                     'volumev2', append=['volumes', self.volume_id, 'action']),
+                     'volumev3', append=['volumes', self.volume_id, 'action']),
                  json={'os-volume_upload_image': {'image_id': self.image_id}},
                  validate=dict(json={
                      u'os-volume_upload_image': {
