@@ -648,6 +648,7 @@ class TestSecurityGroups(base.TestCase):
                     endpoint=fakes.COMPUTE_ENDPOINT,
                 ),
                 json={'security_groups': [nova_grp_dict]}),
+            self.get_nova_discovery_mock_dict(),
             dict(
                 method='POST',
                 uri='%s/servers/%s/action' % (fakes.COMPUTE_ENDPOINT, '1234'),
@@ -705,6 +706,7 @@ class TestSecurityGroups(base.TestCase):
                 uri='{endpoint}/os-security-groups'.format(
                     endpoint=fakes.COMPUTE_ENDPOINT),
                 json={'security_groups': [nova_grp_dict]}),
+            self.get_nova_discovery_mock_dict(),
             dict(
                 method='POST',
                 uri='%s/servers/%s/action' % (fakes.COMPUTE_ENDPOINT, '1234'),
@@ -851,3 +853,91 @@ class TestSecurityGroups(base.TestCase):
         self.assertEqual(nova_grp_dict['id'], ret_sg['id'])
         self.assertEqual(nova_grp_dict['name'], ret_sg['name'])
         self.assert_calls()
+
+    def test_normalize_secgroups(self):
+        nova_secgroup = dict(
+            id='abc123',
+            name='nova_secgroup',
+            description='A Nova security group',
+            rules=[
+                dict(id='123', from_port=80, to_port=81, ip_protocol='tcp',
+                     ip_range={'cidr': '0.0.0.0/0'}, parent_group_id='xyz123')
+            ]
+        )
+        expected = dict(
+            id='abc123',
+            name='nova_secgroup',
+            description='A Nova security group',
+            project_id='',
+            tenant_id='',
+            properties={},
+            location=dict(
+                region_name='RegionOne',
+                zone=None,
+                project=dict(
+                    domain_name='default',
+                    id='1c36b64c840a42cd9e9b931a369337f0',
+                    domain_id=None,
+                    name='admin'),
+                cloud='_test_cloud_'),
+            security_group_rules=[
+                dict(id='123', direction='ingress', ethertype='IPv4',
+                     port_range_min=80, port_range_max=81, protocol='tcp',
+                     remote_ip_prefix='0.0.0.0/0', security_group_id='xyz123',
+                     project_id='', tenant_id='', properties={},
+                     remote_group_id=None,
+                     location=dict(
+                         region_name='RegionOne',
+                         zone=None,
+                         project=dict(
+                             domain_name='default',
+                             id='1c36b64c840a42cd9e9b931a369337f0',
+                             domain_id=None,
+                             name='admin'),
+                         cloud='_test_cloud_'))
+            ]
+        )
+        # Set secgroup source to nova for this test as stateful parameter
+        # is only valid for neutron security groups.
+        self.cloud.secgroup_source = 'nova'
+        retval = self.cloud._normalize_secgroup(nova_secgroup)
+        self.cloud.secgroup_source = 'neutron'
+        self.assertEqual(expected, retval)
+
+    def test_normalize_secgroups_negone_port(self):
+        nova_secgroup = dict(
+            id='abc123',
+            name='nova_secgroup',
+            description='A Nova security group with -1 ports',
+            rules=[
+                dict(id='123', from_port=-1, to_port=-1, ip_protocol='icmp',
+                     ip_range={'cidr': '0.0.0.0/0'}, parent_group_id='xyz123')
+            ]
+        )
+        retval = self.cloud._normalize_secgroup(nova_secgroup)
+        self.assertIsNone(retval['security_group_rules'][0]['port_range_min'])
+        self.assertIsNone(retval['security_group_rules'][0]['port_range_max'])
+
+    def test_normalize_secgroup_rules(self):
+        nova_rules = [
+            dict(id='123', from_port=80, to_port=81, ip_protocol='tcp',
+                 ip_range={'cidr': '0.0.0.0/0'}, parent_group_id='xyz123')
+        ]
+        expected = [
+            dict(id='123', direction='ingress', ethertype='IPv4',
+                 port_range_min=80, port_range_max=81, protocol='tcp',
+                 remote_ip_prefix='0.0.0.0/0', security_group_id='xyz123',
+                 tenant_id='', project_id='', remote_group_id=None,
+                 properties={},
+                 location=dict(
+                     region_name='RegionOne',
+                     zone=None,
+                     project=dict(
+                         domain_name='default',
+                         id='1c36b64c840a42cd9e9b931a369337f0',
+                         domain_id=None,
+                         name='admin'),
+                     cloud='_test_cloud_'))
+        ]
+        retval = self.cloud._normalize_secgroup_rules(nova_rules)
+        self.assertEqual(expected, retval)
