@@ -10,6 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import contextlib
 import datetime
 from unittest import mock
 import uuid
@@ -79,7 +80,8 @@ class TestFlavor(TestComputeProxy):
             self._verify(
                 'openstack.proxy.Proxy._find',
                 self.proxy.find_flavor,
-                method_args=['res', True, True],
+                method_args=['res', True],
+                method_kwargs={'get_extra_specs': True},
                 expected_result=res,
                 expected_args=[flavor.Flavor, 'res'],
                 expected_kwargs={'ignore_missing': True}
@@ -687,27 +689,51 @@ class TestCompute(TestComputeProxy):
     def test_extensions(self):
         self.verify_list(self.proxy.extensions, extension.Extension)
 
+    @contextlib.contextmanager
+    def _check_image_proxy_deprecation_warning(self):
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
+            yield
+            self.assertEqual(1, len(w))
+            self.assertTrue(issubclass(w[-1].category, DeprecationWarning))
+            self.assertIn(
+                "This API is a proxy to the image service ",
+                str(w[-1].message),
+            )
+
     def test_image_delete(self):
-        self.verify_delete(self.proxy.delete_image, image.Image, False)
+        with self._check_image_proxy_deprecation_warning():
+            self.verify_delete(self.proxy.delete_image, image.Image, False)
 
     def test_image_delete_ignore(self):
-        self.verify_delete(self.proxy.delete_image, image.Image, True)
+        with self._check_image_proxy_deprecation_warning():
+            self.verify_delete(self.proxy.delete_image, image.Image, True)
 
     def test_image_find(self):
-        self.verify_find(self.proxy.find_image, image.Image)
+        with self._check_image_proxy_deprecation_warning():
+            self.verify_find(self.proxy.find_image, image.Image)
 
     def test_image_get(self):
-        self.verify_get(self.proxy.get_image, image.Image)
+        with self._check_image_proxy_deprecation_warning():
+            self.verify_get(self.proxy.get_image, image.Image)
 
     def test_images_detailed(self):
-        self.verify_list(self.proxy.images, image.ImageDetail,
-                         method_kwargs={"details": True, "query": 1},
-                         expected_kwargs={"query": 1})
+        with self._check_image_proxy_deprecation_warning():
+            self.verify_list(
+                self.proxy.images,
+                image.ImageDetail,
+                method_kwargs={"details": True, "query": 1},
+                expected_kwargs={"query": 1},
+            )
 
     def test_images_not_detailed(self):
-        self.verify_list(self.proxy.images, image.Image,
-                         method_kwargs={"details": False, "query": 1},
-                         expected_kwargs={"query": 1})
+        with self._check_image_proxy_deprecation_warning():
+            self.verify_list(
+                self.proxy.images,
+                image.Image,
+                method_kwargs={"details": False, "query": 1},
+                expected_kwargs={"query": 1},
+            )
 
     def test_limits_get(self):
         self._verify(
@@ -826,7 +852,11 @@ class TestCompute(TestComputeProxy):
         self.verify_find(
             self.proxy.find_server,
             server.Server,
-            expected_kwargs={'list_base_path': '/servers/detail'},
+            method_kwargs={'all_projects': True},
+            expected_kwargs={
+                'list_base_path': '/servers/detail',
+                'all_projects': True,
+            },
         )
 
     def test_server_get(self):
@@ -1184,8 +1214,12 @@ class TestCompute(TestComputeProxy):
                            server_group.ServerGroup, True)
 
     def test_server_group_find(self):
-        self.verify_find(self.proxy.find_server_group,
-                         server_group.ServerGroup)
+        self.verify_find(
+            self.proxy.find_server_group,
+            server_group.ServerGroup,
+            method_kwargs={'all_projects': True},
+            expected_kwargs={'all_projects': True},
+        )
 
     def test_server_group_get(self):
         self.verify_get(self.proxy.get_server_group,
