@@ -10,9 +10,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import testtools
-
 from openstack.identity.v3 import trust
+from openstack.tests.unit import base
+
 
 IDENTIFIER = 'IDENTIFIER'
 EXAMPLE = {
@@ -32,16 +32,15 @@ EXAMPLE = {
 }
 
 
-class TestTrust(testtools.TestCase):
+class TestTrust(base.TestCase):
 
     def test_basic(self):
         sot = trust.Trust()
         self.assertEqual('trust', sot.resource_key)
         self.assertEqual('trusts', sot.resources_key)
         self.assertEqual('/OS-TRUST/trusts', sot.base_path)
-        self.assertEqual('identity', sot.service.service_type)
         self.assertTrue(sot.allow_create)
-        self.assertTrue(sot.allow_get)
+        self.assertTrue(sot.allow_fetch)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
