@@ -64,20 +64,26 @@ class TestImage(TestImageProxy):
         self._verify(
             "openstack.image.v2.image.Image.import_image",
             self.proxy.import_image,
-            method_args=[original_image, "method", "uri"],
+            method_args=[original_image, "method"],
+            method_kwargs={
+                "uri": "uri",
+            },
             expected_args=[self.proxy],
             expected_kwargs={
                 "method": "method",
                 "store": None,
                 "uri": "uri",
+                "remote_region": None,
+                "remote_image_id": None,
+                "remote_service_interface": None,
                 "stores": [],
                 "all_stores": None,
                 "all_stores_must_succeed": None,
             },
         )
 
-    def test_image_create_conflict(self):
-        self.assertRaises(
+    def test_image_create_conflicting_options(self):
+        exc = self.assertRaises(
             exceptions.SDKException,
             self.proxy.create_image,
             name='fake',
@@ -86,6 +92,25 @@ class TestImage(TestImageProxy):
             container='bare',
             disk_format='raw',
         )
+        self.assertIn('filename and data are mutually exclusive', str(exc))
+
+    def test_image_create_minimal(self):
+        self.verify_create(
+            self.proxy.create_image,
+            _image.Image,
+            method_kwargs={
+                'name': 'fake',
+                'disk_format': 'fake_dformat',
+                'container_format': 'fake_cformat',
+                'allow_duplicates': True,
+            },
+            expected_kwargs={
+                'name': 'fake',
+                'disk_format': 'fake_dformat',
+                'container_format': 'fake_cformat',
+                'properties': mock.ANY,
+            },
+        )
 
     def test_image_create_checksum_match(self):
         fake_image = _image.Image(
@@ -222,22 +247,6 @@ class TestImage(TestImageProxy):
             wait=False,
         )
 
-    def test_image_create_without_filename(self):
-        self.proxy._create_image = mock.Mock()
-
-        self.proxy.create_image(
-            allow_duplicates=True,
-            name='fake',
-            disk_format="fake_dformat",
-            container_format="fake_cformat",
-        )
-        self.proxy._create_image.assert_called_with(
-            container_format='fake_cformat',
-            disk_format='fake_dformat',
-            name='fake',
-            properties=mock.ANY,
-        )
-
     def test_image_create_protected(self):
         self.proxy.find_image = mock.Mock()
 
@@ -314,7 +323,7 @@ class TestImage(TestImageProxy):
         image = _image.Image(id="id", status="queued")
         image.stage = mock.Mock()
 
-        self.proxy.stage_image(image=image)
+        self.proxy.stage_image(image)
         mock_fetch.assert_called()
         image.stage.assert_called_with(self.proxy)
 
@@ -324,22 +333,44 @@ class TestImage(TestImageProxy):
         image.stage = mock.Mock()
         mock_fetch.return_value = image
 
-        rv = self.proxy.stage_image(image=image, data="data")
+        rv = self.proxy.stage_image(image, data="data")
 
         image.stage.assert_called_with(self.proxy)
         mock_fetch.assert_called()
         self.assertEqual(rv.data, "data")
 
+    def test_image_stage_conflicting_options(self):
+        image = _image.Image(id="id", status="queued")
+        image.stage = mock.Mock()
+
+        exc = self.assertRaises(
+            exceptions.SDKException,
+            self.proxy.stage_image,
+            image,
+            filename='foo',
+            data='data',
+        )
+        self.assertIn(
+            'filename and data are mutually exclusive',
+            str(exc),
+        )
+        image.stage.assert_not_called()
+
     def test_image_stage_wrong_status(self):
         image = _image.Image(id="id", status="active")
         image.stage = mock.Mock()
 
-        self.assertRaises(
+        exc = self.assertRaises(
             exceptions.SDKException,
             self.proxy.stage_image,
             image,
-            "data",
+            data="data",
         )
+        self.assertIn(
+            'Image stage is only possible for images in the queued state.',
+            str(exc),
+        )
+        image.stage.assert_not_called()
 
     def test_image_delete(self):
         self.verify_delete(self.proxy.delete_image, _image.Image, False)
