@@ -10,9 +10,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from openstack.network.v2 import port
 from openstack.tests.unit import base
 
-from openstack.network.v2 import port
 
 IDENTIFIER = 'IDENTIFIER'
 EXAMPLE = {
@@ -28,6 +28,7 @@ EXAMPLE = {
     'description': '8',
     'device_id': '9',
     'device_owner': '10',
+    'device_profile': 'cyborg_device_profile_1',
     'dns_assignment': [{'11': 11}],
     'dns_domain': 'a11',
     'dns_name': '12',
@@ -52,7 +53,7 @@ EXAMPLE = {
     'revision_number': 22,
     'security_groups': ['23'],
     'status': '25',
-    'tenant_id': '26',
+    'project_id': '26',
     'trunk_details': {
         'trunk_id': '27',
         'sub_ports': [{
@@ -97,7 +98,7 @@ class TestPort(base.TestCase):
                               "is_admin_state_up": "admin_state_up",
                               "is_port_security_enabled":
                                   "port_security_enabled",
-                              "project_id": "tenant_id",
+                              "project_id": "project_id",
                               "limit": "limit",
                               "marker": "marker",
                               "any_tags": "tags-any",
@@ -122,6 +123,7 @@ class TestPort(base.TestCase):
         self.assertEqual(EXAMPLE['description'], sot.description)
         self.assertEqual(EXAMPLE['device_id'], sot.device_id)
         self.assertEqual(EXAMPLE['device_owner'], sot.device_owner)
+        self.assertEqual(EXAMPLE['device_profile'], sot.device_profile)
         self.assertEqual(EXAMPLE['dns_assignment'], sot.dns_assignment)
         self.assertEqual(EXAMPLE['dns_domain'], sot.dns_domain)
         self.assertEqual(EXAMPLE['dns_name'], sot.dns_name)
@@ -144,6 +146,6 @@ class TestPort(base.TestCase):
         self.assertEqual(EXAMPLE['revision_number'], sot.revision_number)
         self.assertEqual(EXAMPLE['security_groups'], sot.security_group_ids)
         self.assertEqual(EXAMPLE['status'], sot.status)
-        self.assertEqual(EXAMPLE['tenant_id'], sot.project_id)
+        self.assertEqual(EXAMPLE['project_id'], sot.project_id)
         self.assertEqual(EXAMPLE['trunk_details'], sot.trunk_details)
         self.assertEqual(EXAMPLE['updated_at'], sot.updated_at)
